// Generated using `npm run build`. Do not edit!
module.exports = new Map([
	['ASCII', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Any', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Assigned', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['ASCII_Hex_Digit', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Age', new Map([
		['1.1', 'V1_1'],
		['2.0', 'V2_0'],
		['2.1', 'V2_1'],
		['3.0', 'V3_0'],
		['3.1', 'V3_1'],
		['3.2', 'V3_2'],
		['4.0', 'V4_0'],
		['4.1', 'V4_1'],
		['5.0', 'V5_0'],
		['5.1', 'V5_1'],
		['5.2', 'V5_2'],
		['6.0', 'V6_0'],
		['6.1', 'V6_1'],
		['6.2', 'V6_2'],
		['6.3', 'V6_3'],
		['7.0', 'V7_0'],
		['8.0', 'V8_0'],
		['9.0', 'V9_0'],
		['10.0', 'V10_0'],
		['11.0', 'V11_0'],
		['NA', 'Unassigned']
	])],
	['Alphabetic', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Bidi_Class', new Map([
		['AL', 'Arabic_Letter'],
		['AN', 'Arabic_Number'],
		['B', 'Paragraph_Separator'],
		['BN', 'Boundary_Neutral'],
		['CS', 'Common_Separator'],
		['EN', 'European_Number'],
		['ES', 'European_Separator'],
		['ET', 'European_Terminator'],
		['FSI', 'First_Strong_Isolate'],
		['L', 'Left_To_Right'],
		['LRE', 'Left_To_Right_Embedding'],
		['LRI', 'Left_To_Right_Isolate'],
		['LRO', 'Left_To_Right_Override'],
		['NSM', 'Nonspacing_Mark'],
		['ON', 'Other_Neutral'],
		['PDF', 'Pop_Directional_Format'],
		['PDI', 'Pop_Directional_Isolate'],
		['R', 'Right_To_Left'],
		['RLE', 'Right_To_Left_Embedding'],
		['RLI', 'Right_To_Left_Isolate'],
		['RLO', 'Right_To_Left_Override'],
		['S', 'Segment_Separator'],
		['WS', 'White_Space']
	])],
	['Bidi_Control', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Bidi_Mirrored', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Bidi_Paired_Bracket_Type', new Map([
		['c', 'Close'],
		['n', 'None'],
		['o', 'Open']
	])],
	['Block', new Map([
		['Adlam', 'Adlam'],
		['Aegean_Numbers', 'Aegean_Numbers'],
		['Ahom', 'Ahom'],
		['Alchemical', 'Alchemical_Symbols'],
		['Alphabetic_PF', 'Alphabetic_Presentation_Forms'],
		['Anatolian_Hieroglyphs', 'Anatolian_Hieroglyphs'],
		['Ancient_Greek_Music', 'Ancient_Greek_Musical_Notation'],
		['Ancient_Greek_Numbers', 'Ancient_Greek_Numbers'],
		['Ancient_Symbols', 'Ancient_Symbols'],
		['Arabic', 'Arabic'],
		['Arabic_Ext_A', 'Arabic_Extended_A'],
		['Arabic_Math', 'Arabic_Mathematical_Alphabetic_Symbols'],
		['Arabic_PF_A', 'Arabic_Presentation_Forms_A'],
		['Arabic_Presentation_Forms-A', 'Arabic_Presentation_Forms_A'],
		['Arabic_PF_B', 'Arabic_Presentation_Forms_B'],
		['Arabic_Sup', 'Arabic_Supplement'],
		['Armenian', 'Armenian'],
		['Arrows', 'Arrows'],
		['ASCII', 'Basic_Latin'],
		['Avestan', 'Avestan'],
		['Balinese', 'Balinese'],
		['Bamum', 'Bamum'],
		['Bamum_Sup', 'Bamum_Supplement'],
		['Bassa_Vah', 'Bassa_Vah'],
		['Batak', 'Batak'],
		['Bengali', 'Bengali'],
		['Bhaiksuki', 'Bhaiksuki'],
		['Block_Elements', 'Block_Elements'],
		['Bopomofo', 'Bopomofo'],
		['Bopomofo_Ext', 'Bopomofo_Extended'],
		['Box_Drawing', 'Box_Drawing'],
		['Brahmi', 'Brahmi'],
		['Braille', 'Braille_Patterns'],
		['Buginese', 'Buginese'],
		['Buhid', 'Buhid'],
		['Byzantine_Music', 'Byzantine_Musical_Symbols'],
		['Carian', 'Carian'],
		['Caucasian_Albanian', 'Caucasian_Albanian'],
		['Chakma', 'Chakma'],
		['Cham', 'Cham'],
		['Cherokee', 'Cherokee'],
		['Cherokee_Sup', 'Cherokee_Supplement'],
		['Chess_Symbols', 'Chess_Symbols'],
		['CJK', 'CJK_Unified_Ideographs'],
		['CJK_Compat', 'CJK_Compatibility'],
		['CJK_Compat_Forms', 'CJK_Compatibility_Forms'],
		['CJK_Compat_Ideographs', 'CJK_Compatibility_Ideographs'],
		['CJK_Compat_Ideographs_Sup', 'CJK_Compatibility_Ideographs_Supplement'],
		['CJK_Ext_A', 'CJK_Unified_Ideographs_Extension_A'],
		['CJK_Ext_B', 'CJK_Unified_Ideographs_Extension_B'],
		['CJK_Ext_C', 'CJK_Unified_Ideographs_Extension_C'],
		['CJK_Ext_D', 'CJK_Unified_Ideographs_Extension_D'],
		['CJK_Ext_E', 'CJK_Unified_Ideographs_Extension_E'],
		['CJK_Ext_F', 'CJK_Unified_Ideographs_Extension_F'],
		['CJK_Radicals_Sup', 'CJK_Radicals_Supplement'],
		['CJK_Strokes', 'CJK_Strokes'],
		['CJK_Symbols', 'CJK_Symbols_And_Punctuation'],
		['Compat_Jamo', 'Hangul_Compatibility_Jamo'],
		['Control_Pictures', 'Control_Pictures'],
		['Coptic', 'Coptic'],
		['Coptic_Epact_Numbers', 'Coptic_Epact_Numbers'],
		['Counting_Rod', 'Counting_Rod_Numerals'],
		['Cuneiform', 'Cuneiform'],
		['Cuneiform_Numbers', 'Cuneiform_Numbers_And_Punctuation'],
		['Currency_Symbols', 'Currency_Symbols'],
		['Cypriot_Syllabary', 'Cypriot_Syllabary'],
		['Cyrillic', 'Cyrillic'],
		['Cyrillic_Ext_A', 'Cyrillic_Extended_A'],
		['Cyrillic_Ext_B', 'Cyrillic_Extended_B'],
		['Cyrillic_Ext_C', 'Cyrillic_Extended_C'],
		['Cyrillic_Sup', 'Cyrillic_Supplement'],
		['Cyrillic_Supplementary', 'Cyrillic_Supplement'],
		['Deseret', 'Deseret'],
		['Devanagari', 'Devanagari'],
		['Devanagari_Ext', 'Devanagari_Extended'],
		['Diacriticals', 'Combining_Diacritical_Marks'],
		['Diacriticals_Ext', 'Combining_Diacritical_Marks_Extended'],
		['Diacriticals_For_Symbols', 'Combining_Diacritical_Marks_For_Symbols'],
		['Combining_Marks_For_Symbols', 'Combining_Diacritical_Marks_For_Symbols'],
		['Diacriticals_Sup', 'Combining_Diacritical_Marks_Supplement'],
		['Dingbats', 'Dingbats'],
		['Dogra', 'Dogra'],
		['Domino', 'Domino_Tiles'],
		['Duployan', 'Duployan'],
		['Early_Dynastic_Cuneiform', 'Early_Dynastic_Cuneiform'],
		['Egyptian_Hieroglyphs', 'Egyptian_Hieroglyphs'],
		['Elbasan', 'Elbasan'],
		['Emoticons', 'Emoticons'],
		['Enclosed_Alphanum', 'Enclosed_Alphanumerics'],
		['Enclosed_Alphanum_Sup', 'Enclosed_Alphanumeric_Supplement'],
		['Enclosed_CJK', 'Enclosed_CJK_Letters_And_Months'],
		['Enclosed_Ideographic_Sup', 'Enclosed_Ideographic_Supplement'],
		['Ethiopic', 'Ethiopic'],
		['Ethiopic_Ext', 'Ethiopic_Extended'],
		['Ethiopic_Ext_A', 'Ethiopic_Extended_A'],
		['Ethiopic_Sup', 'Ethiopic_Supplement'],
		['Geometric_Shapes', 'Geometric_Shapes'],
		['Geometric_Shapes_Ext', 'Geometric_Shapes_Extended'],
		['Georgian', 'Georgian'],
		['Georgian_Ext', 'Georgian_Extended'],
		['Georgian_Sup', 'Georgian_Supplement'],
		['Glagolitic', 'Glagolitic'],
		['Glagolitic_Sup', 'Glagolitic_Supplement'],
		['Gothic', 'Gothic'],
		['Grantha', 'Grantha'],
		['Greek', 'Greek_And_Coptic'],
		['Greek_Ext', 'Greek_Extended'],
		['Gujarati', 'Gujarati'],
		['Gunjala_Gondi', 'Gunjala_Gondi'],
		['Gurmukhi', 'Gurmukhi'],
		['Half_And_Full_Forms', 'Halfwidth_And_Fullwidth_Forms'],
		['Half_Marks', 'Combining_Half_Marks'],
		['Hangul', 'Hangul_Syllables'],
		['Hanifi_Rohingya', 'Hanifi_Rohingya'],
		['Hanunoo', 'Hanunoo'],
		['Hatran', 'Hatran'],
		['Hebrew', 'Hebrew'],
		['High_PU_Surrogates', 'High_Private_Use_Surrogates'],
		['High_Surrogates', 'High_Surrogates'],
		['Hiragana', 'Hiragana'],
		['IDC', 'Ideographic_Description_Characters'],
		['Ideographic_Symbols', 'Ideographic_Symbols_And_Punctuation'],
		['Imperial_Aramaic', 'Imperial_Aramaic'],
		['Indic_Number_Forms', 'Common_Indic_Number_Forms'],
		['Indic_Siyaq_Numbers', 'Indic_Siyaq_Numbers'],
		['Inscriptional_Pahlavi', 'Inscriptional_Pahlavi'],
		['Inscriptional_Parthian', 'Inscriptional_Parthian'],
		['IPA_Ext', 'IPA_Extensions'],
		['Jamo', 'Hangul_Jamo'],
		['Jamo_Ext_A', 'Hangul_Jamo_Extended_A'],
		['Jamo_Ext_B', 'Hangul_Jamo_Extended_B'],
		['Javanese', 'Javanese'],
		['Kaithi', 'Kaithi'],
		['Kana_Ext_A', 'Kana_Extended_A'],
		['Kana_Sup', 'Kana_Supplement'],
		['Kanbun', 'Kanbun'],
		['Kangxi', 'Kangxi_Radicals'],
		['Kannada', 'Kannada'],
		['Katakana', 'Katakana'],
		['Katakana_Ext', 'Katakana_Phonetic_Extensions'],
		['Kayah_Li', 'Kayah_Li'],
		['Kharoshthi', 'Kharoshthi'],
		['Khmer', 'Khmer'],
		['Khmer_Symbols', 'Khmer_Symbols'],
		['Khojki', 'Khojki'],
		['Khudawadi', 'Khudawadi'],
		['Lao', 'Lao'],
		['Latin_1_Sup', 'Latin_1_Supplement'],
		['Latin_1', 'Latin_1_Supplement'],
		['Latin_Ext_A', 'Latin_Extended_A'],
		['Latin_Ext_Additional', 'Latin_Extended_Additional'],
		['Latin_Ext_B', 'Latin_Extended_B'],
		['Latin_Ext_C', 'Latin_Extended_C'],
		['Latin_Ext_D', 'Latin_Extended_D'],
		['Latin_Ext_E', 'Latin_Extended_E'],
		['Lepcha', 'Lepcha'],
		['Letterlike_Symbols', 'Letterlike_Symbols'],
		['Limbu', 'Limbu'],
		['Linear_A', 'Linear_A'],
		['Linear_B_Ideograms', 'Linear_B_Ideograms'],
		['Linear_B_Syllabary', 'Linear_B_Syllabary'],
		['Lisu', 'Lisu'],
		['Low_Surrogates', 'Low_Surrogates'],
		['Lycian', 'Lycian'],
		['Lydian', 'Lydian'],
		['Mahajani', 'Mahajani'],
		['Mahjong', 'Mahjong_Tiles'],
		['Makasar', 'Makasar'],
		['Malayalam', 'Malayalam'],
		['Mandaic', 'Mandaic'],
		['Manichaean', 'Manichaean'],
		['Marchen', 'Marchen'],
		['Masaram_Gondi', 'Masaram_Gondi'],
		['Math_Alphanum', 'Mathematical_Alphanumeric_Symbols'],
		['Math_Operators', 'Mathematical_Operators'],
		['Mayan_Numerals', 'Mayan_Numerals'],
		['Medefaidrin', 'Medefaidrin'],
		['Meetei_Mayek', 'Meetei_Mayek'],
		['Meetei_Mayek_Ext', 'Meetei_Mayek_Extensions'],
		['Mende_Kikakui', 'Mende_Kikakui'],
		['Meroitic_Cursive', 'Meroitic_Cursive'],
		['Meroitic_Hieroglyphs', 'Meroitic_Hieroglyphs'],
		['Miao', 'Miao'],
		['Misc_Arrows', 'Miscellaneous_Symbols_And_Arrows'],
		['Misc_Math_Symbols_A', 'Miscellaneous_Mathematical_Symbols_A'],
		['Misc_Math_Symbols_B', 'Miscellaneous_Mathematical_Symbols_B'],
		['Misc_Pictographs', 'Miscellaneous_Symbols_And_Pictographs'],
		['Misc_Symbols', 'Miscellaneous_Symbols'],
		['Misc_Technical', 'Miscellaneous_Technical'],
		['Modi', 'Modi'],
		['Modifier_Letters', 'Spacing_Modifier_Letters'],
		['Modifier_Tone_Letters', 'Modifier_Tone_Letters'],
		['Mongolian', 'Mongolian'],
		['Mongolian_Sup', 'Mongolian_Supplement'],
		['Mro', 'Mro'],
		['Multani', 'Multani'],
		['Music', 'Musical_Symbols'],
		['Myanmar', 'Myanmar'],
		['Myanmar_Ext_A', 'Myanmar_Extended_A'],
		['Myanmar_Ext_B', 'Myanmar_Extended_B'],
		['Nabataean', 'Nabataean'],
		['NB', 'No_Block'],
		['New_Tai_Lue', 'New_Tai_Lue'],
		['Newa', 'Newa'],
		['NKo', 'NKo'],
		['Number_Forms', 'Number_Forms'],
		['Nushu', 'Nushu'],
		['OCR', 'Optical_Character_Recognition'],
		['Ogham', 'Ogham'],
		['Ol_Chiki', 'Ol_Chiki'],
		['Old_Hungarian', 'Old_Hungarian'],
		['Old_Italic', 'Old_Italic'],
		['Old_North_Arabian', 'Old_North_Arabian'],
		['Old_Permic', 'Old_Permic'],
		['Old_Persian', 'Old_Persian'],
		['Old_Sogdian', 'Old_Sogdian'],
		['Old_South_Arabian', 'Old_South_Arabian'],
		['Old_Turkic', 'Old_Turkic'],
		['Oriya', 'Oriya'],
		['Ornamental_Dingbats', 'Ornamental_Dingbats'],
		['Osage', 'Osage'],
		['Osmanya', 'Osmanya'],
		['Pahawh_Hmong', 'Pahawh_Hmong'],
		['Palmyrene', 'Palmyrene'],
		['Pau_Cin_Hau', 'Pau_Cin_Hau'],
		['Phags_Pa', 'Phags_Pa'],
		['Phaistos', 'Phaistos_Disc'],
		['Phoenician', 'Phoenician'],
		['Phonetic_Ext', 'Phonetic_Extensions'],
		['Phonetic_Ext_Sup', 'Phonetic_Extensions_Supplement'],
		['Playing_Cards', 'Playing_Cards'],
		['Psalter_Pahlavi', 'Psalter_Pahlavi'],
		['PUA', 'Private_Use_Area'],
		['Private_Use', 'Private_Use_Area'],
		['Punctuation', 'General_Punctuation'],
		['Rejang', 'Rejang'],
		['Rumi', 'Rumi_Numeral_Symbols'],
		['Runic', 'Runic'],
		['Samaritan', 'Samaritan'],
		['Saurashtra', 'Saurashtra'],
		['Sharada', 'Sharada'],
		['Shavian', 'Shavian'],
		['Shorthand_Format_Controls', 'Shorthand_Format_Controls'],
		['Siddham', 'Siddham'],
		['Sinhala', 'Sinhala'],
		['Sinhala_Archaic_Numbers', 'Sinhala_Archaic_Numbers'],
		['Small_Forms', 'Small_Form_Variants'],
		['Sogdian', 'Sogdian'],
		['Sora_Sompeng', 'Sora_Sompeng'],
		['Soyombo', 'Soyombo'],
		['Specials', 'Specials'],
		['Sundanese', 'Sundanese'],
		['Sundanese_Sup', 'Sundanese_Supplement'],
		['Sup_Arrows_A', 'Supplemental_Arrows_A'],
		['Sup_Arrows_B', 'Supplemental_Arrows_B'],
		['Sup_Arrows_C', 'Supplemental_Arrows_C'],
		['Sup_Math_Operators', 'Supplemental_Mathematical_Operators'],
		['Sup_PUA_A', 'Supplementary_Private_Use_Area_A'],
		['Sup_PUA_B', 'Supplementary_Private_Use_Area_B'],
		['Sup_Punctuation', 'Supplemental_Punctuation'],
		['Sup_Symbols_And_Pictographs', 'Supplemental_Symbols_And_Pictographs'],
		['Super_And_Sub', 'Superscripts_And_Subscripts'],
		['Sutton_SignWriting', 'Sutton_SignWriting'],
		['Syloti_Nagri', 'Syloti_Nagri'],
		['Syriac', 'Syriac'],
		['Syriac_Sup', 'Syriac_Supplement'],
		['Tagalog', 'Tagalog'],
		['Tagbanwa', 'Tagbanwa'],
		['Tags', 'Tags'],
		['Tai_Le', 'Tai_Le'],
		['Tai_Tham', 'Tai_Tham'],
		['Tai_Viet', 'Tai_Viet'],
		['Tai_Xuan_Jing', 'Tai_Xuan_Jing_Symbols'],
		['Takri', 'Takri'],
		['Tamil', 'Tamil'],
		['Tangut', 'Tangut'],
		['Tangut_Components', 'Tangut_Components'],
		['Telugu', 'Telugu'],
		['Thaana', 'Thaana'],
		['Thai', 'Thai'],
		['Tibetan', 'Tibetan'],
		['Tifinagh', 'Tifinagh'],
		['Tirhuta', 'Tirhuta'],
		['Transport_And_Map', 'Transport_And_Map_Symbols'],
		['UCAS', 'Unified_Canadian_Aboriginal_Syllabics'],
		['Canadian_Syllabics', 'Unified_Canadian_Aboriginal_Syllabics'],
		['UCAS_Ext', 'Unified_Canadian_Aboriginal_Syllabics_Extended'],
		['Ugaritic', 'Ugaritic'],
		['Vai', 'Vai'],
		['Vedic_Ext', 'Vedic_Extensions'],
		['Vertical_Forms', 'Vertical_Forms'],
		['VS', 'Variation_Selectors'],
		['VS_Sup', 'Variation_Selectors_Supplement'],
		['Warang_Citi', 'Warang_Citi'],
		['Yi_Radicals', 'Yi_Radicals'],
		['Yi_Syllables', 'Yi_Syllables'],
		['Yijing', 'Yijing_Hexagram_Symbols'],
		['Zanabazar_Square', 'Zanabazar_Square']
	])],
	['Canonical_Combining_Class', new Map([
		['NR', 'Not_Reordered'],
		['OV', 'Overlay'],
		['NK', 'Nukta'],
		['KV', 'Kana_Voicing'],
		['VR', 'Virama'],
		['CCC10', 'CCC10'],
		['CCC11', 'CCC11'],
		['CCC12', 'CCC12'],
		['CCC13', 'CCC13'],
		['CCC14', 'CCC14'],
		['CCC15', 'CCC15'],
		['CCC16', 'CCC16'],
		['CCC17', 'CCC17'],
		['CCC18', 'CCC18'],
		['CCC19', 'CCC19'],
		['CCC20', 'CCC20'],
		['CCC21', 'CCC21'],
		['CCC22', 'CCC22'],
		['CCC23', 'CCC23'],
		['CCC24', 'CCC24'],
		['CCC25', 'CCC25'],
		['CCC26', 'CCC26'],
		['CCC27', 'CCC27'],
		['CCC28', 'CCC28'],
		['CCC29', 'CCC29'],
		['CCC30', 'CCC30'],
		['CCC31', 'CCC31'],
		['CCC32', 'CCC32'],
		['CCC33', 'CCC33'],
		['CCC34', 'CCC34'],
		['CCC35', 'CCC35'],
		['CCC36', 'CCC36'],
		['CCC84', 'CCC84'],
		['CCC91', 'CCC91'],
		['CCC103', 'CCC103'],
		['CCC107', 'CCC107'],
		['CCC118', 'CCC118'],
		['CCC122', 'CCC122'],
		['CCC129', 'CCC129'],
		['CCC130', 'CCC130'],
		['CCC132', 'CCC132'],
		['CCC133', 'CCC133'],
		['ATBL', 'Attached_Below_Left'],
		['ATB', 'Attached_Below'],
		['ATA', 'Attached_Above'],
		['ATAR', 'Attached_Above_Right'],
		['BL', 'Below_Left'],
		['B', 'Below'],
		['BR', 'Below_Right'],
		['L', 'Left'],
		['R', 'Right'],
		['AL', 'Above_Left'],
		['A', 'Above'],
		['AR', 'Above_Right'],
		['DB', 'Double_Below'],
		['DA', 'Double_Above'],
		['IS', 'Iota_Subscript']
	])],
	['Case_Ignorable', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Cased', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Changes_When_Casefolded', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Changes_When_Casemapped', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Changes_When_Lowercased', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Changes_When_NFKC_Casefolded', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Changes_When_Titlecased', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Changes_When_Uppercased', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Composition_Exclusion', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Dash', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Decomposition_Type', new Map([
		['Can', 'Canonical'],
		['can', 'Canonical'],
		['Com', 'Compat'],
		['com', 'Compat'],
		['Enc', 'Circle'],
		['enc', 'Circle'],
		['Fin', 'Final'],
		['fin', 'Final'],
		['Font', 'Font'],
		['font', 'Font'],
		['Fra', 'Fraction'],
		['fra', 'Fraction'],
		['Init', 'Initial'],
		['init', 'Initial'],
		['Iso', 'Isolated'],
		['iso', 'Isolated'],
		['Med', 'Medial'],
		['med', 'Medial'],
		['Nar', 'Narrow'],
		['nar', 'Narrow'],
		['Nb', 'Nobreak'],
		['nb', 'Nobreak'],
		['None', 'None'],
		['none', 'None'],
		['Sml', 'Small'],
		['sml', 'Small'],
		['Sqr', 'Square'],
		['sqr', 'Square'],
		['Sub', 'Sub'],
		['sub', 'Sub'],
		['Sup', 'Super'],
		['sup', 'Super'],
		['Vert', 'Vertical'],
		['vert', 'Vertical'],
		['Wide', 'Wide'],
		['wide', 'Wide']
	])],
	['Default_Ignorable_Code_Point', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Deprecated', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Diacritic', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['East_Asian_Width', new Map([
		['A', 'Ambiguous'],
		['F', 'Fullwidth'],
		['H', 'Halfwidth'],
		['N', 'Neutral'],
		['Na', 'Narrow'],
		['W', 'Wide']
	])],
	['Expands_On_NFC', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Expands_On_NFD', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Expands_On_NFKC', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Expands_On_NFKD', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Extender', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Full_Composition_Exclusion', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['General_Category', new Map([
		['C', 'Other'],
		['Cc', 'Control'],
		['cntrl', 'Control'],
		['Cf', 'Format'],
		['Cn', 'Unassigned'],
		['Co', 'Private_Use'],
		['Cs', 'Surrogate'],
		['L', 'Letter'],
		['LC', 'Cased_Letter'],
		['Ll', 'Lowercase_Letter'],
		['Lm', 'Modifier_Letter'],
		['Lo', 'Other_Letter'],
		['Lt', 'Titlecase_Letter'],
		['Lu', 'Uppercase_Letter'],
		['M', 'Mark'],
		['Combining_Mark', 'Mark'],
		['Mc', 'Spacing_Mark'],
		['Me', 'Enclosing_Mark'],
		['Mn', 'Nonspacing_Mark'],
		['N', 'Number'],
		['Nd', 'Decimal_Number'],
		['digit', 'Decimal_Number'],
		['Nl', 'Letter_Number'],
		['No', 'Other_Number'],
		['P', 'Punctuation'],
		['punct', 'Punctuation'],
		['Pc', 'Connector_Punctuation'],
		['Pd', 'Dash_Punctuation'],
		['Pe', 'Close_Punctuation'],
		['Pf', 'Final_Punctuation'],
		['Pi', 'Initial_Punctuation'],
		['Po', 'Other_Punctuation'],
		['Ps', 'Open_Punctuation'],
		['S', 'Symbol'],
		['Sc', 'Currency_Symbol'],
		['Sk', 'Modifier_Symbol'],
		['Sm', 'Math_Symbol'],
		['So', 'Other_Symbol'],
		['Z', 'Separator'],
		['Zl', 'Line_Separator'],
		['Zp', 'Paragraph_Separator'],
		['Zs', 'Space_Separator']
	])],
	['Grapheme_Base', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Grapheme_Cluster_Break', new Map([
		['CN', 'Control'],
		['CR', 'CR'],
		['EB', 'E_Base'],
		['EBG', 'E_Base_GAZ'],
		['EM', 'E_Modifier'],
		['EX', 'Extend'],
		['GAZ', 'Glue_After_Zwj'],
		['L', 'L'],
		['LF', 'LF'],
		['LinkC', 'LinkingConsonant'],
		['LV', 'LV'],
		['LVT', 'LVT'],
		['PP', 'Prepend'],
		['RI', 'Regional_Indicator'],
		['SM', 'SpacingMark'],
		['T', 'T'],
		['V', 'V'],
		['Virama', 'Virama'],
		['XX', 'Other'],
		['ZWJ', 'ZWJ']
	])],
	['Grapheme_Extend', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Grapheme_Link', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Hangul_Syllable_Type', new Map([
		['L', 'Leading_Jamo'],
		['LV', 'LV_Syllable'],
		['LVT', 'LVT_Syllable'],
		['NA', 'Not_Applicable'],
		['T', 'Trailing_Jamo'],
		['V', 'Vowel_Jamo']
	])],
	['Hex_Digit', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Hyphen', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['IDS_Binary_Operator', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['IDS_Trinary_Operator', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['ID_Continue', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['ID_Start', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Ideographic', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Indic_Positional_Category', new Map([
		['Bottom', 'Bottom'],
		['Bottom_And_Left', 'Bottom_And_Left'],
		['Bottom_And_Right', 'Bottom_And_Right'],
		['Left', 'Left'],
		['Left_And_Right', 'Left_And_Right'],
		['NA', 'NA'],
		['Overstruck', 'Overstruck'],
		['Right', 'Right'],
		['Top', 'Top'],
		['Top_And_Bottom', 'Top_And_Bottom'],
		['Top_And_Bottom_And_Right', 'Top_And_Bottom_And_Right'],
		['Top_And_Left', 'Top_And_Left'],
		['Top_And_Left_And_Right', 'Top_And_Left_And_Right'],
		['Top_And_Right', 'Top_And_Right'],
		['Visual_Order_Left', 'Visual_Order_Left']
	])],
	['Indic_Syllabic_Category', new Map([
		['Avagraha', 'Avagraha'],
		['Bindu', 'Bindu'],
		['Brahmi_Joining_Number', 'Brahmi_Joining_Number'],
		['Cantillation_Mark', 'Cantillation_Mark'],
		['Consonant', 'Consonant'],
		['Consonant_Dead', 'Consonant_Dead'],
		['Consonant_Final', 'Consonant_Final'],
		['Consonant_Head_Letter', 'Consonant_Head_Letter'],
		['Consonant_Initial_Postfixed', 'Consonant_Initial_Postfixed'],
		['Consonant_Killer', 'Consonant_Killer'],
		['Consonant_Medial', 'Consonant_Medial'],
		['Consonant_Placeholder', 'Consonant_Placeholder'],
		['Consonant_Preceding_Repha', 'Consonant_Preceding_Repha'],
		['Consonant_Prefixed', 'Consonant_Prefixed'],
		['Consonant_Subjoined', 'Consonant_Subjoined'],
		['Consonant_Succeeding_Repha', 'Consonant_Succeeding_Repha'],
		['Consonant_With_Stacker', 'Consonant_With_Stacker'],
		['Gemination_Mark', 'Gemination_Mark'],
		['Invisible_Stacker', 'Invisible_Stacker'],
		['Joiner', 'Joiner'],
		['Modifying_Letter', 'Modifying_Letter'],
		['Non_Joiner', 'Non_Joiner'],
		['Nukta', 'Nukta'],
		['Number', 'Number'],
		['Number_Joiner', 'Number_Joiner'],
		['Other', 'Other'],
		['Pure_Killer', 'Pure_Killer'],
		['Register_Shifter', 'Register_Shifter'],
		['Syllable_Modifier', 'Syllable_Modifier'],
		['Tone_Letter', 'Tone_Letter'],
		['Tone_Mark', 'Tone_Mark'],
		['Virama', 'Virama'],
		['Visarga', 'Visarga'],
		['Vowel', 'Vowel'],
		['Vowel_Dependent', 'Vowel_Dependent'],
		['Vowel_Independent', 'Vowel_Independent']
	])],
	['Jamo_Short_Name', new Map([
		['A', 'A'],
		['AE', 'AE'],
		['B', 'B'],
		['BB', 'BB'],
		['BS', 'BS'],
		['C', 'C'],
		['D', 'D'],
		['DD', 'DD'],
		['E', 'E'],
		['EO', 'EO'],
		['EU', 'EU'],
		['G', 'G'],
		['GG', 'GG'],
		['GS', 'GS'],
		['H', 'H'],
		['I', 'I'],
		['J', 'J'],
		['JJ', 'JJ'],
		['K', 'K'],
		['L', 'L'],
		['LB', 'LB'],
		['LG', 'LG'],
		['LH', 'LH'],
		['LM', 'LM'],
		['LP', 'LP'],
		['LS', 'LS'],
		['LT', 'LT'],
		['M', 'M'],
		['N', 'N'],
		['NG', 'NG'],
		['NH', 'NH'],
		['NJ', 'NJ'],
		['O', 'O'],
		['OE', 'OE'],
		['P', 'P'],
		['R', 'R'],
		['S', 'S'],
		['SS', 'SS'],
		['T', 'T'],
		['U', 'U'],
		['WA', 'WA'],
		['WAE', 'WAE'],
		['WE', 'WE'],
		['WEO', 'WEO'],
		['WI', 'WI'],
		['YA', 'YA'],
		['YAE', 'YAE'],
		['YE', 'YE'],
		['YEO', 'YEO'],
		['YI', 'YI'],
		['YO', 'YO'],
		['YU', 'YU']
	])],
	['Join_Control', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Joining_Group', new Map([
		['African_Feh', 'African_Feh'],
		['African_Noon', 'African_Noon'],
		['African_Qaf', 'African_Qaf'],
		['Ain', 'Ain'],
		['Alaph', 'Alaph'],
		['Alef', 'Alef'],
		['Beh', 'Beh'],
		['Beth', 'Beth'],
		['Burushaski_Yeh_Barree', 'Burushaski_Yeh_Barree'],
		['Dal', 'Dal'],
		['Dalath_Rish', 'Dalath_Rish'],
		['E', 'E'],
		['Farsi_Yeh', 'Farsi_Yeh'],
		['Fe', 'Fe'],
		['Feh', 'Feh'],
		['Final_Semkath', 'Final_Semkath'],
		['Gaf', 'Gaf'],
		['Gamal', 'Gamal'],
		['Hah', 'Hah'],
		['Hanifi_Rohingya_Kinna_Ya', 'Hanifi_Rohingya_Kinna_Ya'],
		['Hanifi_Rohingya_Pa', 'Hanifi_Rohingya_Pa'],
		['He', 'He'],
		['Heh', 'Heh'],
		['Heh_Goal', 'Heh_Goal'],
		['Heth', 'Heth'],
		['Kaf', 'Kaf'],
		['Kaph', 'Kaph'],
		['Khaph', 'Khaph'],
		['Knotted_Heh', 'Knotted_Heh'],
		['Lam', 'Lam'],
		['Lamadh', 'Lamadh'],
		['Malayalam_Bha', 'Malayalam_Bha'],
		['Malayalam_Ja', 'Malayalam_Ja'],
		['Malayalam_Lla', 'Malayalam_Lla'],
		['Malayalam_Llla', 'Malayalam_Llla'],
		['Malayalam_Nga', 'Malayalam_Nga'],
		['Malayalam_Nna', 'Malayalam_Nna'],
		['Malayalam_Nnna', 'Malayalam_Nnna'],
		['Malayalam_Nya', 'Malayalam_Nya'],
		['Malayalam_Ra', 'Malayalam_Ra'],
		['Malayalam_Ssa', 'Malayalam_Ssa'],
		['Malayalam_Tta', 'Malayalam_Tta'],
		['Manichaean_Aleph', 'Manichaean_Aleph'],
		['Manichaean_Ayin', 'Manichaean_Ayin'],
		['Manichaean_Beth', 'Manichaean_Beth'],
		['Manichaean_Daleth', 'Manichaean_Daleth'],
		['Manichaean_Dhamedh', 'Manichaean_Dhamedh'],
		['Manichaean_Five', 'Manichaean_Five'],
		['Manichaean_Gimel', 'Manichaean_Gimel'],
		['Manichaean_Heth', 'Manichaean_Heth'],
		['Manichaean_Hundred', 'Manichaean_Hundred'],
		['Manichaean_Kaph', 'Manichaean_Kaph'],
		['Manichaean_Lamedh', 'Manichaean_Lamedh'],
		['Manichaean_Mem', 'Manichaean_Mem'],
		['Manichaean_Nun', 'Manichaean_Nun'],
		['Manichaean_One', 'Manichaean_One'],
		['Manichaean_Pe', 'Manichaean_Pe'],
		['Manichaean_Qoph', 'Manichaean_Qoph'],
		['Manichaean_Resh', 'Manichaean_Resh'],
		['Manichaean_Sadhe', 'Manichaean_Sadhe'],
		['Manichaean_Samekh', 'Manichaean_Samekh'],
		['Manichaean_Taw', 'Manichaean_Taw'],
		['Manichaean_Ten', 'Manichaean_Ten'],
		['Manichaean_Teth', 'Manichaean_Teth'],
		['Manichaean_Thamedh', 'Manichaean_Thamedh'],
		['Manichaean_Twenty', 'Manichaean_Twenty'],
		['Manichaean_Waw', 'Manichaean_Waw'],
		['Manichaean_Yodh', 'Manichaean_Yodh'],
		['Manichaean_Zayin', 'Manichaean_Zayin'],
		['Meem', 'Meem'],
		['Mim', 'Mim'],
		['No_Joining_Group', 'No_Joining_Group'],
		['Noon', 'Noon'],
		['Nun', 'Nun'],
		['Nya', 'Nya'],
		['Pe', 'Pe'],
		['Qaf', 'Qaf'],
		['Qaph', 'Qaph'],
		['Reh', 'Reh'],
		['Reversed_Pe', 'Reversed_Pe'],
		['Rohingya_Yeh', 'Rohingya_Yeh'],
		['Sad', 'Sad'],
		['Sadhe', 'Sadhe'],
		['Seen', 'Seen'],
		['Semkath', 'Semkath'],
		['Shin', 'Shin'],
		['Straight_Waw', 'Straight_Waw'],
		['Swash_Kaf', 'Swash_Kaf'],
		['Syriac_Waw', 'Syriac_Waw'],
		['Tah', 'Tah'],
		['Taw', 'Taw'],
		['Teh_Marbuta', 'Teh_Marbuta'],
		['Teh_Marbuta_Goal', 'Hamza_On_Heh_Goal'],
		['Teth', 'Teth'],
		['Waw', 'Waw'],
		['Yeh', 'Yeh'],
		['Yeh_Barree', 'Yeh_Barree'],
		['Yeh_With_Tail', 'Yeh_With_Tail'],
		['Yudh', 'Yudh'],
		['Yudh_He', 'Yudh_He'],
		['Zain', 'Zain'],
		['Zhain', 'Zhain']
	])],
	['Joining_Type', new Map([
		['C', 'Join_Causing'],
		['D', 'Dual_Joining'],
		['L', 'Left_Joining'],
		['R', 'Right_Joining'],
		['T', 'Transparent'],
		['U', 'Non_Joining']
	])],
	['Line_Break', new Map([
		['AI', 'Ambiguous'],
		['AL', 'Alphabetic'],
		['B2', 'Break_Both'],
		['BA', 'Break_After'],
		['BB', 'Break_Before'],
		['BK', 'Mandatory_Break'],
		['CB', 'Contingent_Break'],
		['CJ', 'Conditional_Japanese_Starter'],
		['CL', 'Close_Punctuation'],
		['CM', 'Combining_Mark'],
		['CP', 'Close_Parenthesis'],
		['CR', 'Carriage_Return'],
		['EB', 'E_Base'],
		['EM', 'E_Modifier'],
		['EX', 'Exclamation'],
		['GL', 'Glue'],
		['H2', 'H2'],
		['H3', 'H3'],
		['HL', 'Hebrew_Letter'],
		['HY', 'Hyphen'],
		['ID', 'Ideographic'],
		['IN', 'Inseparable'],
		['Inseperable', 'Inseparable'],
		['IS', 'Infix_Numeric'],
		['JL', 'JL'],
		['JT', 'JT'],
		['JV', 'JV'],
		['LF', 'Line_Feed'],
		['NL', 'Next_Line'],
		['NS', 'Nonstarter'],
		['NU', 'Numeric'],
		['OP', 'Open_Punctuation'],
		['PO', 'Postfix_Numeric'],
		['PR', 'Prefix_Numeric'],
		['QU', 'Quotation'],
		['RI', 'Regional_Indicator'],
		['SA', 'Complex_Context'],
		['SG', 'Surrogate'],
		['SP', 'Space'],
		['SY', 'Break_Symbols'],
		['WJ', 'Word_Joiner'],
		['XX', 'Unknown'],
		['ZW', 'ZWSpace'],
		['ZWJ', 'ZWJ']
	])],
	['Logical_Order_Exception', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Lowercase', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Math', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['NFC_Quick_Check', new Map([
		['M', 'Maybe'],
		['N', 'No'],
		['Y', 'Yes']
	])],
	['NFD_Quick_Check', new Map([
		['N', 'No'],
		['Y', 'Yes']
	])],
	['NFKC_Quick_Check', new Map([
		['M', 'Maybe'],
		['N', 'No'],
		['Y', 'Yes']
	])],
	['NFKD_Quick_Check', new Map([
		['N', 'No'],
		['Y', 'Yes']
	])],
	['Noncharacter_Code_Point', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Numeric_Type', new Map([
		['De', 'Decimal'],
		['Di', 'Digit'],
		['None', 'None'],
		['Nu', 'Numeric']
	])],
	['Other_Alphabetic', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Other_Default_Ignorable_Code_Point', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Other_Grapheme_Extend', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Other_ID_Continue', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Other_ID_Start', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Other_Lowercase', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Other_Math', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Other_Uppercase', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Pattern_Syntax', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Pattern_White_Space', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Prepended_Concatenation_Mark', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Quotation_Mark', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Radical', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Regional_Indicator', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Script', new Map([
		['Adlm', 'Adlam'],
		['Aghb', 'Caucasian_Albanian'],
		['Ahom', 'Ahom'],
		['Arab', 'Arabic'],
		['Armi', 'Imperial_Aramaic'],
		['Armn', 'Armenian'],
		['Avst', 'Avestan'],
		['Bali', 'Balinese'],
		['Bamu', 'Bamum'],
		['Bass', 'Bassa_Vah'],
		['Batk', 'Batak'],
		['Beng', 'Bengali'],
		['Bhks', 'Bhaiksuki'],
		['Bopo', 'Bopomofo'],
		['Brah', 'Brahmi'],
		['Brai', 'Braille'],
		['Bugi', 'Buginese'],
		['Buhd', 'Buhid'],
		['Cakm', 'Chakma'],
		['Cans', 'Canadian_Aboriginal'],
		['Cari', 'Carian'],
		['Cham', 'Cham'],
		['Cher', 'Cherokee'],
		['Copt', 'Coptic'],
		['Qaac', 'Coptic'],
		['Cprt', 'Cypriot'],
		['Cyrl', 'Cyrillic'],
		['Deva', 'Devanagari'],
		['Dogr', 'Dogra'],
		['Dsrt', 'Deseret'],
		['Dupl', 'Duployan'],
		['Egyp', 'Egyptian_Hieroglyphs'],
		['Elba', 'Elbasan'],
		['Ethi', 'Ethiopic'],
		['Geor', 'Georgian'],
		['Glag', 'Glagolitic'],
		['Gong', 'Gunjala_Gondi'],
		['Gonm', 'Masaram_Gondi'],
		['Goth', 'Gothic'],
		['Gran', 'Grantha'],
		['Grek', 'Greek'],
		['Gujr', 'Gujarati'],
		['Guru', 'Gurmukhi'],
		['Hang', 'Hangul'],
		['Hani', 'Han'],
		['Hano', 'Hanunoo'],
		['Hatr', 'Hatran'],
		['Hebr', 'Hebrew'],
		['Hira', 'Hiragana'],
		['Hluw', 'Anatolian_Hieroglyphs'],
		['Hmng', 'Pahawh_Hmong'],
		['Hrkt', 'Katakana_Or_Hiragana'],
		['Hung', 'Old_Hungarian'],
		['Ital', 'Old_Italic'],
		['Java', 'Javanese'],
		['Kali', 'Kayah_Li'],
		['Kana', 'Katakana'],
		['Khar', 'Kharoshthi'],
		['Khmr', 'Khmer'],
		['Khoj', 'Khojki'],
		['Knda', 'Kannada'],
		['Kthi', 'Kaithi'],
		['Lana', 'Tai_Tham'],
		['Laoo', 'Lao'],
		['Latn', 'Latin'],
		['Lepc', 'Lepcha'],
		['Limb', 'Limbu'],
		['Lina', 'Linear_A'],
		['Linb', 'Linear_B'],
		['Lisu', 'Lisu'],
		['Lyci', 'Lycian'],
		['Lydi', 'Lydian'],
		['Mahj', 'Mahajani'],
		['Maka', 'Makasar'],
		['Mand', 'Mandaic'],
		['Mani', 'Manichaean'],
		['Marc', 'Marchen'],
		['Medf', 'Medefaidrin'],
		['Mend', 'Mende_Kikakui'],
		['Merc', 'Meroitic_Cursive'],
		['Mero', 'Meroitic_Hieroglyphs'],
		['Mlym', 'Malayalam'],
		['Modi', 'Modi'],
		['Mong', 'Mongolian'],
		['Mroo', 'Mro'],
		['Mtei', 'Meetei_Mayek'],
		['Mult', 'Multani'],
		['Mymr', 'Myanmar'],
		['Narb', 'Old_North_Arabian'],
		['Nbat', 'Nabataean'],
		['Newa', 'Newa'],
		['Nkoo', 'Nko'],
		['Nshu', 'Nushu'],
		['Ogam', 'Ogham'],
		['Olck', 'Ol_Chiki'],
		['Orkh', 'Old_Turkic'],
		['Orya', 'Oriya'],
		['Osge', 'Osage'],
		['Osma', 'Osmanya'],
		['Palm', 'Palmyrene'],
		['Pauc', 'Pau_Cin_Hau'],
		['Perm', 'Old_Permic'],
		['Phag', 'Phags_Pa'],
		['Phli', 'Inscriptional_Pahlavi'],
		['Phlp', 'Psalter_Pahlavi'],
		['Phnx', 'Phoenician'],
		['Plrd', 'Miao'],
		['Prti', 'Inscriptional_Parthian'],
		['Rjng', 'Rejang'],
		['Rohg', 'Hanifi_Rohingya'],
		['Runr', 'Runic'],
		['Samr', 'Samaritan'],
		['Sarb', 'Old_South_Arabian'],
		['Saur', 'Saurashtra'],
		['Sgnw', 'SignWriting'],
		['Shaw', 'Shavian'],
		['Shrd', 'Sharada'],
		['Sidd', 'Siddham'],
		['Sind', 'Khudawadi'],
		['Sinh', 'Sinhala'],
		['Sogd', 'Sogdian'],
		['Sogo', 'Old_Sogdian'],
		['Sora', 'Sora_Sompeng'],
		['Soyo', 'Soyombo'],
		['Sund', 'Sundanese'],
		['Sylo', 'Syloti_Nagri'],
		['Syrc', 'Syriac'],
		['Tagb', 'Tagbanwa'],
		['Takr', 'Takri'],
		['Tale', 'Tai_Le'],
		['Talu', 'New_Tai_Lue'],
		['Taml', 'Tamil'],
		['Tang', 'Tangut'],
		['Tavt', 'Tai_Viet'],
		['Telu', 'Telugu'],
		['Tfng', 'Tifinagh'],
		['Tglg', 'Tagalog'],
		['Thaa', 'Thaana'],
		['Thai', 'Thai'],
		['Tibt', 'Tibetan'],
		['Tirh', 'Tirhuta'],
		['Ugar', 'Ugaritic'],
		['Vaii', 'Vai'],
		['Wara', 'Warang_Citi'],
		['Xpeo', 'Old_Persian'],
		['Xsux', 'Cuneiform'],
		['Yiii', 'Yi'],
		['Zanb', 'Zanabazar_Square'],
		['Zinh', 'Inherited'],
		['Qaai', 'Inherited'],
		['Zyyy', 'Common'],
		['Zzzz', 'Unknown']
	])],
	['Sentence_Break', new Map([
		['AT', 'ATerm'],
		['CL', 'Close'],
		['CR', 'CR'],
		['EX', 'Extend'],
		['FO', 'Format'],
		['LE', 'OLetter'],
		['LF', 'LF'],
		['LO', 'Lower'],
		['NU', 'Numeric'],
		['SC', 'SContinue'],
		['SE', 'Sep'],
		['SP', 'Sp'],
		['ST', 'STerm'],
		['UP', 'Upper'],
		['XX', 'Other']
	])],
	['Sentence_Terminal', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Soft_Dotted', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Terminal_Punctuation', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Unified_Ideograph', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Uppercase', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Variation_Selector', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Vertical_Orientation', new Map([
		['R', 'Rotated'],
		['Tr', 'Transformed_Rotated'],
		['Tu', 'Transformed_Upright'],
		['U', 'Upright']
	])],
	['White_Space', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Word_Break', new Map([
		['CR', 'CR'],
		['DQ', 'Double_Quote'],
		['EB', 'E_Base'],
		['EBG', 'E_Base_GAZ'],
		['EM', 'E_Modifier'],
		['EX', 'ExtendNumLet'],
		['Extend', 'Extend'],
		['FO', 'Format'],
		['GAZ', 'Glue_After_Zwj'],
		['HL', 'Hebrew_Letter'],
		['KA', 'Katakana'],
		['LE', 'ALetter'],
		['LF', 'LF'],
		['MB', 'MidNumLet'],
		['ML', 'MidLetter'],
		['MN', 'MidNum'],
		['NL', 'Newline'],
		['NU', 'Numeric'],
		['RI', 'Regional_Indicator'],
		['SQ', 'Single_Quote'],
		['WSegSpace', 'WSegSpace'],
		['XX', 'Other'],
		['ZWJ', 'ZWJ']
	])],
	['XID_Continue', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['XID_Start', new Map([
		['N', 'No'],
		['F', 'No'],
		['False', 'No'],
		['Y', 'Yes'],
		['T', 'Yes'],
		['True', 'Yes']
	])],
	['Script_Extensions', new Map([
		['Adlm', 'Adlam'],
		['Aghb', 'Caucasian_Albanian'],
		['Ahom', 'Ahom'],
		['Arab', 'Arabic'],
		['Armi', 'Imperial_Aramaic'],
		['Armn', 'Armenian'],
		['Avst', 'Avestan'],
		['Bali', 'Balinese'],
		['Bamu', 'Bamum'],
		['Bass', 'Bassa_Vah'],
		['Batk', 'Batak'],
		['Beng', 'Bengali'],
		['Bhks', 'Bhaiksuki'],
		['Bopo', 'Bopomofo'],
		['Brah', 'Brahmi'],
		['Brai', 'Braille'],
		['Bugi', 'Buginese'],
		['Buhd', 'Buhid'],
		['Cakm', 'Chakma'],
		['Cans', 'Canadian_Aboriginal'],
		['Cari', 'Carian'],
		['Cham', 'Cham'],
		['Cher', 'Cherokee'],
		['Copt', 'Coptic'],
		['Qaac', 'Coptic'],
		['Cprt', 'Cypriot'],
		['Cyrl', 'Cyrillic'],
		['Deva', 'Devanagari'],
		['Dogr', 'Dogra'],
		['Dsrt', 'Deseret'],
		['Dupl', 'Duployan'],
		['Egyp', 'Egyptian_Hieroglyphs'],
		['Elba', 'Elbasan'],
		['Ethi', 'Ethiopic'],
		['Geor', 'Georgian'],
		['Glag', 'Glagolitic'],
		['Gong', 'Gunjala_Gondi'],
		['Gonm', 'Masaram_Gondi'],
		['Goth', 'Gothic'],
		['Gran', 'Grantha'],
		['Grek', 'Greek'],
		['Gujr', 'Gujarati'],
		['Guru', 'Gurmukhi'],
		['Hang', 'Hangul'],
		['Hani', 'Han'],
		['Hano', 'Hanunoo'],
		['Hatr', 'Hatran'],
		['Hebr', 'Hebrew'],
		['Hira', 'Hiragana'],
		['Hluw', 'Anatolian_Hieroglyphs'],
		['Hmng', 'Pahawh_Hmong'],
		['Hrkt', 'Katakana_Or_Hiragana'],
		['Hung', 'Old_Hungarian'],
		['Ital', 'Old_Italic'],
		['Java', 'Javanese'],
		['Kali', 'Kayah_Li'],
		['Kana', 'Katakana'],
		['Khar', 'Kharoshthi'],
		['Khmr', 'Khmer'],
		['Khoj', 'Khojki'],
		['Knda', 'Kannada'],
		['Kthi', 'Kaithi'],
		['Lana', 'Tai_Tham'],
		['Laoo', 'Lao'],
		['Latn', 'Latin'],
		['Lepc', 'Lepcha'],
		['Limb', 'Limbu'],
		['Lina', 'Linear_A'],
		['Linb', 'Linear_B'],
		['Lisu', 'Lisu'],
		['Lyci', 'Lycian'],
		['Lydi', 'Lydian'],
		['Mahj', 'Mahajani'],
		['Maka', 'Makasar'],
		['Mand', 'Mandaic'],
		['Mani', 'Manichaean'],
		['Marc', 'Marchen'],
		['Medf', 'Medefaidrin'],
		['Mend', 'Mende_Kikakui'],
		['Merc', 'Meroitic_Cursive'],
		['Mero', 'Meroitic_Hieroglyphs'],
		['Mlym', 'Malayalam'],
		['Modi', 'Modi'],
		['Mong', 'Mongolian'],
		['Mroo', 'Mro'],
		['Mtei', 'Meetei_Mayek'],
		['Mult', 'Multani'],
		['Mymr', 'Myanmar'],
		['Narb', 'Old_North_Arabian'],
		['Nbat', 'Nabataean'],
		['Newa', 'Newa'],
		['Nkoo', 'Nko'],
		['Nshu', 'Nushu'],
		['Ogam', 'Ogham'],
		['Olck', 'Ol_Chiki'],
		['Orkh', 'Old_Turkic'],
		['Orya', 'Oriya'],
		['Osge', 'Osage'],
		['Osma', 'Osmanya'],
		['Palm', 'Palmyrene'],
		['Pauc', 'Pau_Cin_Hau'],
		['Perm', 'Old_Permic'],
		['Phag', 'Phags_Pa'],
		['Phli', 'Inscriptional_Pahlavi'],
		['Phlp', 'Psalter_Pahlavi'],
		['Phnx', 'Phoenician'],
		['Plrd', 'Miao'],
		['Prti', 'Inscriptional_Parthian'],
		['Rjng', 'Rejang'],
		['Rohg', 'Hanifi_Rohingya'],
		['Runr', 'Runic'],
		['Samr', 'Samaritan'],
		['Sarb', 'Old_South_Arabian'],
		['Saur', 'Saurashtra'],
		['Sgnw', 'SignWriting'],
		['Shaw', 'Shavian'],
		['Shrd', 'Sharada'],
		['Sidd', 'Siddham'],
		['Sind', 'Khudawadi'],
		['Sinh', 'Sinhala'],
		['Sogd', 'Sogdian'],
		['Sogo', 'Old_Sogdian'],
		['Sora', 'Sora_Sompeng'],
		['Soyo', 'Soyombo'],
		['Sund', 'Sundanese'],
		['Sylo', 'Syloti_Nagri'],
		['Syrc', 'Syriac'],
		['Tagb', 'Tagbanwa'],
		['Takr', 'Takri'],
		['Tale', 'Tai_Le'],
		['Talu', 'New_Tai_Lue'],
		['Taml', 'Tamil'],
		['Tang', 'Tangut'],
		['Tavt', 'Tai_Viet'],
		['Telu', 'Telugu'],
		['Tfng', 'Tifinagh'],
		['Tglg', 'Tagalog'],
		['Thaa', 'Thaana'],
		['Thai', 'Thai'],
		['Tibt', 'Tibetan'],
		['Tirh', 'Tirhuta'],
		['Ugar', 'Ugaritic'],
		['Vaii', 'Vai'],
		['Wara', 'Warang_Citi'],
		['Xpeo', 'Old_Persian'],
		['Xsux', 'Cuneiform'],
		['Yiii', 'Yi'],
		['Zanb', 'Zanabazar_Square'],
		['Zinh', 'Inherited'],
		['Qaai', 'Inherited'],
		['Zyyy', 'Common'],
		['Zzzz', 'Unknown']
	])]
]);
